/*******************************************************************************
* FILE NAME: print_routines.c
*
* DESCRIPTION:
*  This file contains debug print routines.  
*
* USAGE:
*
*******************************************************************************/

#include "print_routines.h"

#include "ifi_aliases.h"
#include "ifi_default.h"
#include "ifi_utilities.h"
#include "user_routines.h"

#include <string.h>
#include <stdlib.h>


/******* Print utilities *******/
/*
*                The printf supplied isn't efficient and isn't comprehensive.
*                Leaving it out saves 4300 bytes 0r 13% of the total program memory 
*                available.
*                PrintString - prints fixed, unchanging strings (rom)
*                PrintMyString - prints strings constructed on-the-fly (ram)
*                PrintCR - print a carrage return to go to a new line
*                PrintDecimal - print an unsigned number of any type (must be type-cast)
*                PrintSignedDecimal - print a signed number of any type
*                DisplayBufr - print a Hexidecimal dump of the Master uP input or output
*                PacketNum_Check - print the current radio packet number
*
*     There are 38 lines in the IFI_Loader debug window.
*/

  extern char ifi_printfBufr[]; /* declared in ifi_utilities.c */


/*******************************************************************************
* FUNCTION NAME: PrintRamString
* PURPOSE:       Print a string to the IFI_Loader debug window.
*                Same as PrintString, but takes a data memory string.
* CALLED FROM:   anywhere
* ARGUMENTS:     none
*     Input: bufr - pointer to data memory string.
* RETURNS:       void
*******************************************************************************/
void PrintRamString(char *bufr)
{
  static int len,I;
    
  strcpy (ifi_printfBufr,(ram char *) bufr); /*Move from ram to ram*/
  len = (int) strlen((const char *)ifi_printfBufr);
  if (len > 80) len = 80;

  for (I=0;I<len;I++)
  {
    TXREG = ifi_printfBufr[I];
    Wait4TXEmpty();
  }
}

/*******************************************************************************
* FUNCTION NAME: PrintCR
* PURPOSE:       Print a carriage return to the IFI_Loader debug window.
* CALLED FROM:   anywhere
* ARGUMENTS:     none
* RETURNS:       void
*******************************************************************************/
void PrintCR(void)
{
    TXREG = 13;
    Wait4TXEmpty();
}


/*******************************************************************************
* FUNCTION NAME: PrintDecimal
* PURPOSE:       Print decimal data to the IFI_Loader debug window.
* Sample Call:   PrintDecimal((unsigned long) secondCount);
*                For any type unsigned char,int,or long
* CALLED FROM:   anywhere
* ARGUMENTS:     none
*     Input: odata - char,int, or long to be printed, must be type-cast(unsigned long) first 
* RETURNS:       void
*******************************************************************************/
void PrintDecimal(unsigned long odata)
{
  /* Convert to string */
  ultoa(odata, ifi_printfBufr);
  PrintRamString(ifi_printfBufr);
}

/*******************************************************************************
* FUNCTION NAME: PrintSignedDecimal
* PURPOSE:       Print signed decimal data to the IFI_Loader debug window.
* CALLED FROM:   anywhere
* ARGUMENTS:     none
*     Input:odata - char,int, or long to be printed, must be type-cast(long) first
* RETURNS:       void
*******************************************************************************/
void PrintSignedDecimal(long odata)
{
  /* Convert to string */
  ltoa(odata, ifi_printfBufr);
  PrintRamString(ifi_printfBufr);
}

